@@ -129,92 +129,6 @@ class Motor(OutputModule):
         self.__set_motor_channel(1, 1, speed_value)
         self.update_property(Motor.SECOND_SPEED, speed_value)
 
-    @property
-    def first_torque(self) -> float:
-        """Returns first torque
-
-        :return: first torque value
-        :rtype: float
-        """
-        return self._get_property(Motor.FIRST_TORQUE)
-
-    @first_torque.setter
-    @OutputModule._validate_property(nb_values=1, value_range=(-100, 100))
-    def first_torque(self, torque_value: int) -> None:
-        """Set the torque of the motor at channel I
-
-        :param torque_value: Torque to set the first motor.
-        :type torque_value: int
-        :return: None
-        """
-        _ = self.first_torque
-        self._set_property(
-            self.id,
-            Motor.TORQUE,
-            (torque_value, self.second_torque),
-        )
-        # self.set_motor_channel(0, 0, torque_value)
-        self.update_property(Motor.FIRST_TORQUE, torque_value)
-
-    @property
-    def second_torque(self) -> float:
-        """Returns second torque
-
-        :return: second torque value
-        :rtype: float
-        """
-        return self._get_property(Motor.SECOND_TORQUE)
-
-    @second_torque.setter
-    @OutputModule._validate_property(nb_values=1, value_range=(-100, 100))
-    def second_torque(self, torque_value: int) -> None:
-        """Set the torque of the motor at channel II
-
-        :param torque_value: Torque to set the second motor.
-        :type torque_value: int
-        :return: None
-        """
-        _ = self.second_torque
-        self._set_property(
-            self.id,
-            Motor.TORQUE,
-            (self.first_torque, torque_value),
-        )
-        # self.set_motor_channel(1, 0, torque_value)
-        self.update_property(Motor.SECOND_TORQUE, torque_value)
-
-    @property
-    def torque(self) -> Tuple[float, float]:
-        """Returns torque values of two motors
-
-        :return: Torque
-        :rtype: Tuple[float, float]
-        """
-        return (
-            self._get_property(Motor.FIRST_TORQUE),
-            self._get_property(Motor.SECOND_TORQUE),
-        )
-
-    @torque.setter
-    @OutputModule._validate_property(nb_values=2, value_range=(-100, 100))
-    def torque(self, torque_value: Tuple[int, int]) -> None:
-        """Set the torque of the motors at both channels
-
-        :param torque_value: Torque to set motor
-        :type torque_value: Tuple[int, int]
-        :return: None
-        """
-        _ = self.torque
-        self._set_property(
-            self.id,
-            Motor.TORQUE,
-            torque_value,
-        )
-        # self.set_motor_channel(0, 0, torque_value[0])
-        # self.set_motor_channel(1, 0, torque_value[1])
-        self.update_property(Motor.FIRST_TORQUE, torque_value[0])
-        self.update_property(Motor.SECOND_TORQUE, torque_value[1])
-
     @property
     def speed(self):
         """Returns speed value of two motors
