@@ -6,7 +6,7 @@ from typing import Dict, Tuple, Optional
 import can
 
 from modi.task.conn_task import ConnTask
-from modi.util.conn_util import MODIConnectionError
+from modi.util.connection_util import MODIConnectionError
 
 
 class CanTask(ConnTask):
