@@ -1,8 +1,8 @@
 import unittest
 
 from modi.module.input_module.ir import Ir
-from modi.util.msgutil import parse_message
-from modi.util.misc import MockConn
+from modi.util.message_util import parse_message
+from modi.util.miscellaneous import MockConn
 
 
 class TestIr(unittest.TestCase):
